IOData
======
[![Build Status](https://travis-ci.org/theochem/iodata.svg?branch=master)](https://travis-ci.org/theochem/iodata)
<a href='https://docs.python.org/2.7/'><img src='https://img.shields.io/badge/python-2.7-blue.svg'></a>
<a href='https://docs.python.org/3.5/'><img src='https://img.shields.io/badge/python-3.5-blue.svg'></a>
[![codecov](https://codecov.io/gh/theochem/iodata/branch/master/graph/badge.svg)](https://codecov.io/gh/theochem/iodata)
[![Build status](https://ci.appveyor.com/api/projects/status/s1v03mj127dmoi7s/branch/master?svg=true)](https://ci.appveyor.com/project/theochem-ci-bot/iodata/branch/master)


About
-----


License
-------

IOData is distributed under GPL License version 3 (GPLv3).


Dependencies
------------

The following dependencies will be necessary for IOData to build properly,

* Python >= 2.7, >= 3.5: http://www.python.org/
* SciPy >= 0.11.0: http://www.scipy.org/
* NumPy >= 1.9.1: http://www.numpy.org/
* Nosetests >= 1.1.2: http://readthedocs.org/docs/nose/en/latest/


Installation
------------

To install IOData:

```bash
python ./setup install --user
```


Testing
-------

To run tests:

```bash
nosetests -v iodata
```
